@@ -3,4 +3,5 @@ Corporate Number Parser Library
 ~~~~~~~~~~~~~~~~~~~~~
 cnparser is a simple scraping library for Corporate Number Publication Site
 """
-from cnparser.load import bulk_load, bulk_enrich
+from cnparser.load import load, read_csv
+from cnparser.enrich import enrich
\ No newline at end of file
